# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class FriendlyInvoice(UncheckedBaseModel):
    id: str
    url: typing.Optional[str] = None
    pdf: typing.Optional[str] = None
    amount_due: int
    friendly_plan: str
    timestamp_start: int
    friendly_amount_due: typing.Optional[str] = None
    friendly_date: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
