# This file was auto-generated by Fern from our API Definition.

import typing

NativeScorerConfigType = typing.Union[
    typing.Literal["exact_match", "contains", "regex_match", "field_exists", "type_check"], typing.Any
]
