# This file was auto-generated by Fern from our API Definition.

import typing

from .documents_update_request_value import DocumentsUpdateRequestValue

DocumentsUpdateRequest = typing.Dict[str, typing.Optional[DocumentsUpdateRequestValue]]
