# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .create_drive_node_request_resource_type import CreateDriveNodeRequestResourceType


class CreateDriveNodeRequest(UncheckedBaseModel):
    resource_type: CreateDriveNodeRequestResourceType = pydantic.Field()
    """
    Type of resource (tables, workflow, crawl, file, integration, directory)
    """

    resource_path: str = pydantic.Field()
    """
    Full path for the node (e.g., '/Projects/MyWorkflow')
    """

    resource_id: str = pydantic.Field()
    """
    ID of the underlying resource (ignored for directories)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
