# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class PromptTarget(UncheckedBaseModel):
    """
    Prompt template evaluation target (future).

    Evaluates prompt templates with different models.

    Example:
        target = PromptTarget(
            type="prompt",
            prompt_template_id="prompt_product_description",
            model="claude-sonnet-4"
        )
    """

    type: typing.Literal["prompt"] = "prompt"
    revision_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Specific revision/version to evaluate
    """

    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Target-specific metadata
    """

    prompt_template_id: str = pydantic.Field()
    """
    Prompt template ID to evaluate
    """

    model: typing.Optional[str] = pydantic.Field(default=None)
    """
    Model to execute prompt with
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
