# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_directive import AgentDirective
from .ephemeral_agent_directive import EphemeralAgentDirective

AgentScheduleAgentDirectivesItem = typing.Union[AgentDirective, EphemeralAgentDirective]
