# This file was auto-generated by Fern from our API Definition.

import typing

TypeCheckAssertionExpectedType = typing.Union[
    typing.Literal["str", "int", "float", "bool", "list", "dict", "null"], typing.Any
]
