# This file was auto-generated by Fern from our API Definition.

import typing

FeedbackTargetType = typing.Union[
    typing.Literal["workflow_run", "copilot_message", "agent_session", "span", "trace"], typing.Any
]
