# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class DriveFileMessage(UncheckedBaseModel):
    type: typing.Literal["drive_file"] = pydantic.Field(default="drive_file")
    """
    The type of entity: 'drive_file'
    """

    path: str = pydantic.Field()
    """
    Drive file path for 'drive_file' entities (e.g., '/Reports/Q1.pdf')
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
