# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .create_agent_schedule_body_instructions_item import CreateAgentScheduleBodyInstructionsItem


class CreateAgentScheduleBody(UncheckedBaseModel):
    """
    Create a schedule for a single persisted agent.
    """

    name: typing.Optional[str] = None
    cron_expression: str = pydantic.Field()
    """
    CRON expression that defines when the schedule runs
    """

    timezone: typing.Optional[str] = pydantic.Field(default=None)
    """
    IANA timezone for this schedule (e.g. 'UTC', 'America/New_York')
    """

    agent_revision_id: typing.Optional[str] = None
    instructions: typing.List[CreateAgentScheduleBodyInstructionsItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
