# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_scorer import AgentScorer
from .human_review_scorer import HumanReviewScorer
from .native_scorer import NativeScorer

CreateScorerRequestScorer = typing.Union[AgentScorer, HumanReviewScorer, NativeScorer]
