# This file was auto-generated by Fern from our API Definition.

import typing

ConnectIntegrationRequestAuthType = typing.Union[
    typing.Literal["oauth2", "oauth2_custom", "api_key", "mcp"], typing.Any
]
