# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .run_evaluation_request_target_override import RunEvaluationRequestTargetOverride


class RunEvaluationRequest(UncheckedBaseModel):
    """
    Request to run a saved evaluation with optional target override
    """

    target_override: typing.Optional[RunEvaluationRequestTargetOverride] = pydantic.Field(default=None)
    """
    Optional target override. Allows running the same test cases against a different agent/workflow/revision without modifying the saved config.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
