# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .evaluate_check_agent import EvaluateCheckAgent
from .evaluate_check_ai import EvaluateCheckAi


class EvaluateCheck(UncheckedBaseModel):
    """
    A single check - discriminated union
    """

    field_exists: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    exact_match: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    contains: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    regex_match: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    type_check: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    agent: typing.Optional[EvaluateCheckAgent] = None
    ai: typing.Optional[EvaluateCheckAi] = None
    scorer: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
