# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .date_time_column_date_format import DateTimeColumnDateFormat
from .date_time_column_time_format import DateTimeColumnTimeFormat
from .typescript_automation_config import TypescriptAutomationConfig


class DateTimeColumn(UncheckedBaseModel):
    column_id: typing.Optional[str] = None
    column_display_name: typing.Optional[str] = None
    column_type: typing.Literal["datetime"] = "datetime"
    data_type: typing.Optional[typing.Literal["datetime"]] = None
    hidden: typing.Optional[bool] = None
    automation_config: TypescriptAutomationConfig = pydantic.Field()
    """
    Optional automation configuration to automatically calculate values for this column
    """

    default: typing.Optional[dt.datetime] = None
    include_time: typing.Optional[bool] = None
    date_format: typing.Optional[DateTimeColumnDateFormat] = None
    time_format: typing.Optional[DateTimeColumnTimeFormat] = None
    time_zone: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
