# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_feedback_request_priority import UpdateFeedbackRequestPriority
from .update_feedback_request_status import UpdateFeedbackRequestStatus


class UpdateFeedbackRequest(UncheckedBaseModel):
    """
    Request to update existing feedback
    """

    score: typing.Optional[float] = None
    selected_option: typing.Optional[str] = None
    comment: typing.Optional[str] = None
    correction: typing.Optional[typing.Optional[typing.Any]] = None
    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    status: typing.Optional[UpdateFeedbackRequestStatus] = None
    priority: typing.Optional[UpdateFeedbackRequestPriority] = None
    assigned_to: typing.Optional[str] = None
    internal_notes: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
