# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class SourceSyncGoogleDriveSettings(UncheckedBaseModel):
    source_archetype_id: typing.Literal["com.google.drive"] = "com.google.drive"
    connection_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Which Google Drive connection to sync from.
    """

    filter_options: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Narrow down resources you sync from the source. Ensure you include fetch_filters method on Source Sync Archetype.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
