# This file was auto-generated by Fern from our API Definition.

import typing

GuidedStepAction = typing.Union[
    typing.Literal["navigate", "click", "fill", "wait", "scrape", "download_pdf"], typing.Any
]
