# This file was auto-generated by Fern from our API Definition.

import typing

AssertionResultAssertionType = typing.Union[
    typing.Literal[
        "exact_match", "contains", "regex_match", "semantic_similarity", "field_exists", "type_check", "llm_judge"
    ],
    typing.Any,
]
