# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_target import AgentTarget
from .byo_target import ByoTarget
from .prompt_target import PromptTarget
from .tool_target import ToolTarget
from .workflow_target import WorkflowTarget

RunEvaluationRequestTargetOverride = typing.Union[AgentTarget, ByoTarget, PromptTarget, ToolTarget, WorkflowTarget]
