# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class FieldPath(UncheckedBaseModel):
    """
    Available field path in workflow output
    """

    path: str = pydantic.Field()
    """
    Field path (e.g., 'block_id.output.field')
    """

    type: str = pydantic.Field()
    """
    Field type (string, number, array, object)
    """

    sample_value: typing.Optional[typing.Optional[typing.Any]] = pydantic.Field(default=None)
    """
    Sample value from output
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
