# This file was auto-generated by Fern from our API Definition.

import contextlib
import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.request_options import RequestOptions
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from ..types.src_app_http_routes_drive_sdk_drive_upload_response import SrcAppHttpRoutesDriveSdkDriveUploadResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawDriveClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def upload(
        self,
        *,
        files: typing.List[core.File],
        metadata: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SrcAppHttpRoutesDriveSdkDriveUploadResponse]:
        """
        Upload one or more files to Drive.

        - `files`: the file uploads (multipart)
        - `metadata`: a JSON string containing a list of per-file metadata dicts,
          positionally aligned with `files`. Each dict may contain:
            - `path`   — fully qualified destination path (takes precedence)
            - `folder` — destination folder
            - `name`   — destination filename

        Resolution logic for each file at index i:
        - If path is provided, use it as the fully qualified path
        - Else if folder and name are provided, combine as {folder}/{name}
        - Else if folder is provided, combine as {folder}/{upload_filename}
        - Else if name is provided, use /{name} (root)
        - Else fall back to None (domain default behavior)

        Parameters
        ----------
        files : typing.List[core.File]
            See core.File for more documentation

        metadata : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesDriveSdkDriveUploadResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "drive/upload",
            method="POST",
            data={
                "metadata": metadata,
            },
            files={
                "files": files,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesDriveSdkDriveUploadResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesDriveSdkDriveUploadResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    @contextlib.contextmanager
    def download(
        self,
        *,
        path: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        folder: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[HttpResponse[typing.Iterator[bytes]]]:
        """
        Download a single file from Drive.

        Provide one of the following to identify the file:
        - `path`: fully qualified path (e.g., '/foo/bar/hello.txt')
        - `name` + `folder`: file name within a specific folder (e.g., name='hello.txt', folder='/foo/bar')

        Returns the file content as a streaming binary response.

        Parameters
        ----------
        path : typing.Optional[str]
            Fully qualified path to the file (e.g., '/foo/bar/hello.txt')

        name : typing.Optional[str]
            File name to search for (e.g., 'hello.txt')

        folder : typing.Optional[str]
            Folder to search within (e.g., '/foo/bar')

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[HttpResponse[typing.Iterator[bytes]]]
            Successful Response
        """
        with self._client_wrapper.httpx_client.stream(
            "drive/download",
            method="GET",
            params={
                "path": path,
                "name": name,
                "folder": folder,
            },
            request_options=request_options,
        ) as _response:

            def _stream() -> HttpResponse[typing.Iterator[bytes]]:
                try:
                    if 200 <= _response.status_code < 300:
                        _chunk_size = request_options.get("chunk_size", None) if request_options is not None else None
                        return HttpResponse(
                            response=_response, data=(_chunk for _chunk in _response.iter_bytes(chunk_size=_chunk_size))
                        )
                    _response.read()
                    if _response.status_code == 422:
                        raise UnprocessableEntityError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                HttpValidationError,
                                construct_type(
                                    type_=HttpValidationError,  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield _stream()


class AsyncRawDriveClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def upload(
        self,
        *,
        files: typing.List[core.File],
        metadata: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SrcAppHttpRoutesDriveSdkDriveUploadResponse]:
        """
        Upload one or more files to Drive.

        - `files`: the file uploads (multipart)
        - `metadata`: a JSON string containing a list of per-file metadata dicts,
          positionally aligned with `files`. Each dict may contain:
            - `path`   — fully qualified destination path (takes precedence)
            - `folder` — destination folder
            - `name`   — destination filename

        Resolution logic for each file at index i:
        - If path is provided, use it as the fully qualified path
        - Else if folder and name are provided, combine as {folder}/{name}
        - Else if folder is provided, combine as {folder}/{upload_filename}
        - Else if name is provided, use /{name} (root)
        - Else fall back to None (domain default behavior)

        Parameters
        ----------
        files : typing.List[core.File]
            See core.File for more documentation

        metadata : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesDriveSdkDriveUploadResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "drive/upload",
            method="POST",
            data={
                "metadata": metadata,
            },
            files={
                "files": files,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesDriveSdkDriveUploadResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesDriveSdkDriveUploadResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    @contextlib.asynccontextmanager
    async def download(
        self,
        *,
        path: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        folder: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[bytes]]]:
        """
        Download a single file from Drive.

        Provide one of the following to identify the file:
        - `path`: fully qualified path (e.g., '/foo/bar/hello.txt')
        - `name` + `folder`: file name within a specific folder (e.g., name='hello.txt', folder='/foo/bar')

        Returns the file content as a streaming binary response.

        Parameters
        ----------
        path : typing.Optional[str]
            Fully qualified path to the file (e.g., '/foo/bar/hello.txt')

        name : typing.Optional[str]
            File name to search for (e.g., 'hello.txt')

        folder : typing.Optional[str]
            Folder to search within (e.g., '/foo/bar')

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[bytes]]]
            Successful Response
        """
        async with self._client_wrapper.httpx_client.stream(
            "drive/download",
            method="GET",
            params={
                "path": path,
                "name": name,
                "folder": folder,
            },
            request_options=request_options,
        ) as _response:

            async def _stream() -> AsyncHttpResponse[typing.AsyncIterator[bytes]]:
                try:
                    if 200 <= _response.status_code < 300:
                        _chunk_size = request_options.get("chunk_size", None) if request_options is not None else None
                        return AsyncHttpResponse(
                            response=_response,
                            data=(_chunk async for _chunk in _response.aiter_bytes(chunk_size=_chunk_size)),
                        )
                    await _response.aread()
                    if _response.status_code == 422:
                        raise UnprocessableEntityError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                HttpValidationError,
                                construct_type(
                                    type_=HttpValidationError,  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield await _stream()
