# This file was auto-generated by Fern from our API Definition.

import typing

from .blob_asset_content import BlobAssetContent
from .blob_url_content import BlobUrlContent
from .cta_response import CtaResponse
from .incoming_serializable_entity_content_six_item import IncomingSerializableEntityContentSixItem
from .text_content import TextContent

IncomingSerializableEntityContent = typing.Union[
    str,
    typing.Dict[str, typing.Optional[typing.Any]],
    TextContent,
    BlobUrlContent,
    BlobAssetContent,
    CtaResponse,
    typing.List[IncomingSerializableEntityContentSixItem],
]
