# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class FieldExistsAssertion(UncheckedBaseModel):
    """
    Field exists assertion.

    Checks if a specific field exists in the output (regardless of value).

    Example:
        assertion = FieldExistsAssertion(
            type="field_exists",
            field_path="user.id",
            description="User ID should be present"
        )
    """

    type: typing.Literal["field_exists"] = "field_exists"
    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Human-readable description of this assertion
    """

    field_path: str = pydantic.Field()
    """
    JSON path to field (required for this assertion type)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
