# This file was auto-generated by Fern from our API Definition.

import typing

SourceSyncMicrosoft365SettingsTranscriptionMethod = typing.Union[
    typing.Literal["document_ai", "asset_manager"], typing.Any
]
