# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_execute import AgentExecute
from .source_sync import SourceSync
from .workflow_execute import WorkflowExecute

SlackTriggerConfigOutputAction = typing.Union[AgentExecute, SourceSync, WorkflowExecute]
