# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class ByoTarget(UncheckedBaseModel):
    """
    Bring Your Own outputs target.

    For evaluating pre-computed outputs without execution.
    Used by POST /evaluation/evaluate endpoint.

    Example:
        target = BYOTarget(
            type="byo",
            source="local_function"
        )
    """

    type: typing.Literal["byo"] = "byo"
    revision_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Specific revision/version to evaluate
    """

    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Target-specific metadata
    """

    source: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional description of output source (e.g., 'local_function', 'external_api')
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
