# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class CredentialMapping(UncheckedBaseModel):
    """
    Maps a form field to a secret reference for secure credential injection.
    """

    field_selector: str = pydantic.Field()
    """
    CSS selector for the input field
    """

    secret_ref: str = pydantic.Field()
    """
    Secret reference in format 'secrets.secret_name' (e.g., 'secrets.portal_username')
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
