# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .field_path import FieldPath


class WorkflowPreviewResponse(UncheckedBaseModel):
    """
    Workflow preview execution response
    """

    ok: typing.Optional[bool] = None
    execution: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Workflow execution result with run_id and output
    """

    available_paths: typing.Optional[typing.List[FieldPath]] = pydantic.Field(default=None)
    """
    Available field paths from output
    """

    message: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
