# This file was auto-generated by Fern from our API Definition.

import typing

ScoutHookEventTriggerType = typing.Union[
    typing.Literal["agent.interaction.responded"],
    typing.Literal["studio_table.row.updated"],
    typing.Literal["studio_table.row.created"],
    str,
]
