# This file was auto-generated by Fern from our API Definition.

import typing

from .incoming_serializable_entity import IncomingSerializableEntity

CreateAgentScheduleBodyInstructionsItem = typing.Union[str, IncomingSerializableEntity]
