# This file was auto-generated by Fern from our API Definition.

import typing

from .drive_file_message import DriveFileMessage
from .incoming_message_content_two_item import IncomingMessageContentTwoItem

IncomingMessageContent = typing.Union[str, DriveFileMessage, typing.List[IncomingMessageContentTwoItem]]
