# This file was auto-generated by Fern from our API Definition.

import typing

from .contains_assertion import ContainsAssertion
from .exact_match_assertion import ExactMatchAssertion
from .field_exists_assertion import FieldExistsAssertion
from .llm_judge_assertion import LlmJudgeAssertion
from .regex_match_assertion import RegexMatchAssertion
from .semantic_similarity_assertion import SemanticSimilarityAssertion
from .type_check_assertion import TypeCheckAssertion

TestCaseAssertionsItem = typing.Union[
    ContainsAssertion,
    ExactMatchAssertion,
    FieldExistsAssertion,
    LlmJudgeAssertion,
    RegexMatchAssertion,
    SemanticSimilarityAssertion,
    TypeCheckAssertion,
]
