# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class ExecuteScorerResponse(UncheckedBaseModel):
    """
    Execute scorer response
    """

    ok: typing.Optional[bool] = None
    passed: bool
    overall_score: float
    detailed_scores: typing.Optional[typing.Dict[str, float]] = None
    reasoning: str
    execution_time_ms: int
    session_id: typing.Optional[str] = None
    model: typing.Optional[str] = None
    error: typing.Optional[str] = None
    message: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
